<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'Google\\Site_Kit_Dependencies\\Firebase\\JWT\\BeforeValidException' => $baseDir . '/firebase/php-jwt/src/BeforeValidException.php',
    'Google\\Site_Kit_Dependencies\\Firebase\\JWT\\CachedKeySet' => $baseDir . '/firebase/php-jwt/src/CachedKeySet.php',
    'Google\\Site_Kit_Dependencies\\Firebase\\JWT\\ExpiredException' => $baseDir . '/firebase/php-jwt/src/ExpiredException.php',
    'Google\\Site_Kit_Dependencies\\Firebase\\JWT\\JWK' => $baseDir . '/firebase/php-jwt/src/JWK.php',
    'Google\\Site_Kit_Dependencies\\Firebase\\JWT\\JWT' => $baseDir . '/firebase/php-jwt/src/JWT.php',
    'Google\\Site_Kit_Dependencies\\Firebase\\JWT\\JWTExceptionWithPayloadInterface' => $baseDir . '/firebase/php-jwt/src/JWTExceptionWithPayloadInterface.php',
    'Google\\Site_Kit_Dependencies\\Firebase\\JWT\\Key' => $baseDir . '/firebase/php-jwt/src/Key.php',
    'Google\\Site_Kit_Dependencies\\Firebase\\JWT\\SignatureInvalidException' => $baseDir . '/firebase/php-jwt/src/SignatureInvalidException.php',
    'Google\\Site_Kit_Dependencies\\Google\\AccessToken\\Revoke' => $baseDir . '/google/apiclient/src/AccessToken/Revoke.php',
    'Google\\Site_Kit_Dependencies\\Google\\AccessToken\\Verify' => $baseDir . '/google/apiclient/src/AccessToken/Verify.php',
    'Google\\Site_Kit_Dependencies\\Google\\AuthHandler\\AuthHandlerFactory' => $baseDir . '/google/apiclient/src/AuthHandler/AuthHandlerFactory.php',
    'Google\\Site_Kit_Dependencies\\Google\\AuthHandler\\Guzzle6AuthHandler' => $baseDir . '/google/apiclient/src/AuthHandler/Guzzle6AuthHandler.php',
    'Google\\Site_Kit_Dependencies\\Google\\AuthHandler\\Guzzle7AuthHandler' => $baseDir . '/google/apiclient/src/AuthHandler/Guzzle7AuthHandler.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\AccessToken' => $baseDir . '/google/auth/src/AccessToken.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\ApplicationDefaultCredentials' => $baseDir . '/google/auth/src/ApplicationDefaultCredentials.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\CacheTrait' => $baseDir . '/google/auth/src/CacheTrait.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Cache\\InvalidArgumentException' => $baseDir . '/google/auth/src/Cache/InvalidArgumentException.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Cache\\Item' => $baseDir . '/google/auth/src/Cache/Item.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Cache\\MemoryCacheItemPool' => $baseDir . '/google/auth/src/Cache/MemoryCacheItemPool.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Cache\\SysVCacheItemPool' => $baseDir . '/google/auth/src/Cache/SysVCacheItemPool.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Cache\\TypedItem' => $baseDir . '/google/auth/src/Cache/TypedItem.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\CredentialSource\\AwsNativeSource' => $baseDir . '/google/auth/src/CredentialSource/AwsNativeSource.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\CredentialSource\\FileSource' => $baseDir . '/google/auth/src/CredentialSource/FileSource.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\CredentialSource\\UrlSource' => $baseDir . '/google/auth/src/CredentialSource/UrlSource.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\CredentialsLoader' => $baseDir . '/google/auth/src/CredentialsLoader.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Credentials\\AppIdentityCredentials' => $baseDir . '/google/auth/src/Credentials/AppIdentityCredentials.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Credentials\\ExternalAccountCredentials' => $baseDir . '/google/auth/src/Credentials/ExternalAccountCredentials.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Credentials\\GCECredentials' => $baseDir . '/google/auth/src/Credentials/GCECredentials.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Credentials\\IAMCredentials' => $baseDir . '/google/auth/src/Credentials/IAMCredentials.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Credentials\\ImpersonatedServiceAccountCredentials' => $baseDir . '/google/auth/src/Credentials/ImpersonatedServiceAccountCredentials.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Credentials\\InsecureCredentials' => $baseDir . '/google/auth/src/Credentials/InsecureCredentials.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Credentials\\ServiceAccountCredentials' => $baseDir . '/google/auth/src/Credentials/ServiceAccountCredentials.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Credentials\\ServiceAccountJwtAccessCredentials' => $baseDir . '/google/auth/src/Credentials/ServiceAccountJwtAccessCredentials.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Credentials\\UserRefreshCredentials' => $baseDir . '/google/auth/src/Credentials/UserRefreshCredentials.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\ExternalAccountCredentialSourceInterface' => $baseDir . '/google/auth/src/ExternalAccountCredentialSourceInterface.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\FetchAuthTokenCache' => $baseDir . '/google/auth/src/FetchAuthTokenCache.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\FetchAuthTokenInterface' => $baseDir . '/google/auth/src/FetchAuthTokenInterface.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\GCECache' => $baseDir . '/google/auth/src/GCECache.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\GetQuotaProjectInterface' => $baseDir . '/google/auth/src/GetQuotaProjectInterface.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\GetUniverseDomainInterface' => $baseDir . '/google/auth/src/GetUniverseDomainInterface.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\HttpHandler\\Guzzle6HttpHandler' => $baseDir . '/google/auth/src/HttpHandler/Guzzle6HttpHandler.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\HttpHandler\\Guzzle7HttpHandler' => $baseDir . '/google/auth/src/HttpHandler/Guzzle7HttpHandler.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\HttpHandler\\HttpClientCache' => $baseDir . '/google/auth/src/HttpHandler/HttpClientCache.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\HttpHandler\\HttpHandlerFactory' => $baseDir . '/google/auth/src/HttpHandler/HttpHandlerFactory.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Iam' => $baseDir . '/google/auth/src/Iam.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\IamSignerTrait' => $baseDir . '/google/auth/src/IamSignerTrait.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Middleware\\AuthTokenMiddleware' => $baseDir . '/google/auth/src/Middleware/AuthTokenMiddleware.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Middleware\\ProxyAuthTokenMiddleware' => $baseDir . '/google/auth/src/Middleware/ProxyAuthTokenMiddleware.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Middleware\\ScopedAccessTokenMiddleware' => $baseDir . '/google/auth/src/Middleware/ScopedAccessTokenMiddleware.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\Middleware\\SimpleMiddleware' => $baseDir . '/google/auth/src/Middleware/SimpleMiddleware.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\OAuth2' => $baseDir . '/google/auth/src/OAuth2.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\ProjectIdProviderInterface' => $baseDir . '/google/auth/src/ProjectIdProviderInterface.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\ServiceAccountSignerTrait' => $baseDir . '/google/auth/src/ServiceAccountSignerTrait.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\SignBlobInterface' => $baseDir . '/google/auth/src/SignBlobInterface.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\UpdateMetadataInterface' => $baseDir . '/google/auth/src/UpdateMetadataInterface.php',
    'Google\\Site_Kit_Dependencies\\Google\\Auth\\UpdateMetadataTrait' => $baseDir . '/google/auth/src/UpdateMetadataTrait.php',
    'Google\\Site_Kit_Dependencies\\Google\\Client' => $baseDir . '/google/apiclient/src/Client.php',
    'Google\\Site_Kit_Dependencies\\Google\\Collection' => $baseDir . '/google/apiclient/src/Collection.php',
    'Google\\Site_Kit_Dependencies\\Google\\Exception' => $baseDir . '/google/apiclient/src/Exception.php',
    'Google\\Site_Kit_Dependencies\\Google\\Http\\Batch' => $baseDir . '/google/apiclient/src/Http/Batch.php',
    'Google\\Site_Kit_Dependencies\\Google\\Http\\MediaFileUpload' => $baseDir . '/google/apiclient/src/Http/MediaFileUpload.php',
    'Google\\Site_Kit_Dependencies\\Google\\Http\\REST' => $baseDir . '/google/apiclient/src/Http/REST.php',
    'Google\\Site_Kit_Dependencies\\Google\\Model' => $baseDir . '/google/apiclient/src/Model.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service' => $baseDir . '/google/apiclient/src/Service.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Account' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Account.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\AdBlockingRecoveryTag' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/AdBlockingRecoveryTag.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\AdClient' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/AdClient.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\AdClientAdCode' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/AdClientAdCode.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\AdUnit' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/AdUnit.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\AdUnitAdCode' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/AdUnitAdCode.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\AdsenseEmpty' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/AdsenseEmpty.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Alert' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Alert.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Cell' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Cell.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\ContentAdsSettings' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/ContentAdsSettings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\CustomChannel' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/CustomChannel.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Date' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Date.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Header' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Header.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\HttpBody' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/HttpBody.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\ListAccountsResponse' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/ListAccountsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\ListAdClientsResponse' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/ListAdClientsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\ListAdUnitsResponse' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/ListAdUnitsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\ListAlertsResponse' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/ListAlertsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\ListChildAccountsResponse' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/ListChildAccountsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\ListCustomChannelsResponse' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/ListCustomChannelsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\ListLinkedAdUnitsResponse' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/ListLinkedAdUnitsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\ListLinkedCustomChannelsResponse' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/ListLinkedCustomChannelsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\ListPaymentsResponse' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/ListPaymentsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\ListPolicyIssuesResponse' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/ListPolicyIssuesResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\ListSavedReportsResponse' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/ListSavedReportsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\ListSitesResponse' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/ListSitesResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\ListUrlChannelsResponse' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/ListUrlChannelsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Payment' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Payment.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\PolicyIssue' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/PolicyIssue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\PolicyTopic' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/PolicyTopic.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\ReportResult' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/ReportResult.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Resource\\Accounts' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Resource/Accounts.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Resource\\AccountsAdclients' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Resource/AccountsAdclients.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Resource\\AccountsAdclientsAdunits' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Resource/AccountsAdclientsAdunits.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Resource\\AccountsAdclientsCustomchannels' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Resource/AccountsAdclientsCustomchannels.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Resource\\AccountsAdclientsUrlchannels' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Resource/AccountsAdclientsUrlchannels.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Resource\\AccountsAlerts' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Resource/AccountsAlerts.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Resource\\AccountsPayments' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Resource/AccountsPayments.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Resource\\AccountsPolicyIssues' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Resource/AccountsPolicyIssues.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Resource\\AccountsReports' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Resource/AccountsReports.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Resource\\AccountsReportsSaved' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Resource/AccountsReportsSaved.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Resource\\AccountsSites' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Resource/AccountsSites.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Row' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Row.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\SavedReport' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/SavedReport.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\Site' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/Site.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\TimeZone' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/TimeZone.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Adsense\\UrlChannel' => $baseDir . '/google/apiclient-services-adsense.v2/src/Adsense/UrlChannel.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\ActiveMetricRestriction' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/ActiveMetricRestriction.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\AudienceExport' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/AudienceExport.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\AudienceListMetadata' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/AudienceListMetadata.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\BatchRunPivotReportsRequest' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/BatchRunPivotReportsRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\BatchRunPivotReportsResponse' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/BatchRunPivotReportsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\BatchRunReportsRequest' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/BatchRunReportsRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\BatchRunReportsResponse' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/BatchRunReportsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\BetweenFilter' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/BetweenFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\CaseExpression' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/CaseExpression.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\CheckCompatibilityRequest' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/CheckCompatibilityRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\CheckCompatibilityResponse' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/CheckCompatibilityResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\Cohort' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/Cohort.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\CohortReportSettings' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/CohortReportSettings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\CohortSpec' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/CohortSpec.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\CohortsRange' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/CohortsRange.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\Comparison' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/Comparison.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\ComparisonMetadata' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/ComparisonMetadata.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\ConcatenateExpression' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/ConcatenateExpression.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\DateRange' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/DateRange.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\Dimension' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/Dimension.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\DimensionCompatibility' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/DimensionCompatibility.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\DimensionExpression' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/DimensionExpression.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\DimensionHeader' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/DimensionHeader.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\DimensionMetadata' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/DimensionMetadata.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\DimensionOrderBy' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/DimensionOrderBy.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\DimensionValue' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/DimensionValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\EmptyFilter' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/EmptyFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\Filter' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/Filter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\FilterExpression' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/FilterExpression.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\FilterExpressionList' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/FilterExpressionList.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\InListFilter' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/InListFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\ListAudienceExportsResponse' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/ListAudienceExportsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\Metadata' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/Metadata.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\Metric' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/Metric.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\MetricCompatibility' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/MetricCompatibility.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\MetricHeader' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/MetricHeader.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\MetricMetadata' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/MetricMetadata.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\MetricOrderBy' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/MetricOrderBy.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\MetricValue' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/MetricValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\MinuteRange' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/MinuteRange.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\NumericFilter' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/NumericFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\NumericValue' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/NumericValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\Operation' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/Operation.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\OrderBy' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/OrderBy.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\Pivot' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/Pivot.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\PivotDimensionHeader' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/PivotDimensionHeader.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\PivotHeader' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/PivotHeader.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\PivotOrderBy' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/PivotOrderBy.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\PivotSelection' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/PivotSelection.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\PropertyQuota' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/PropertyQuota.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\QueryAudienceExportRequest' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/QueryAudienceExportRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\QueryAudienceExportResponse' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/QueryAudienceExportResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\QuotaStatus' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/QuotaStatus.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\Resource\\Properties' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/Resource/Properties.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\Resource\\PropertiesAudienceExports' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/Resource/PropertiesAudienceExports.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\ResponseMetaData' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/ResponseMetaData.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\Row' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/Row.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\RunPivotReportRequest' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/RunPivotReportRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\RunPivotReportResponse' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/RunPivotReportResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\RunRealtimeReportRequest' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/RunRealtimeReportRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\RunRealtimeReportResponse' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/RunRealtimeReportResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\RunReportRequest' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/RunReportRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\RunReportResponse' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/RunReportResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\SamplingMetadata' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/SamplingMetadata.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\SchemaRestrictionResponse' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/SchemaRestrictionResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\Status' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/Status.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\StringFilter' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/StringFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\V1betaAudienceDimension' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/V1betaAudienceDimension.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\V1betaAudienceDimensionValue' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/V1betaAudienceDimensionValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\AnalyticsData\\V1betaAudienceRow' => $baseDir . '/google/apiclient-services-analyticsdata.v1beta/src/AnalyticsData/V1betaAudienceRow.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Exception' => $baseDir . '/google/apiclient/src/Service/Exception.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessBetweenFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessBetweenFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessBinding' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessBinding.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessDateRange' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessDateRange.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessDimension' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessDimension.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessDimensionHeader' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessDimensionHeader.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessDimensionValue' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessDimensionValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessFilterExpression' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessFilterExpression.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessFilterExpressionList' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessFilterExpressionList.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessInListFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessInListFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessMetric' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessMetric.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessMetricHeader' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessMetricHeader.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessMetricValue' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessMetricValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessNumericFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessNumericFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessOrderBy' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessOrderBy.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessOrderByDimensionOrderBy' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessOrderByDimensionOrderBy.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessOrderByMetricOrderBy' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessOrderByMetricOrderBy.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessQuota' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessQuota.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessQuotaStatus' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessQuotaStatus.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessRow' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessRow.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccessStringFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccessStringFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccount' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccount.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAccountSummary' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAccountSummary.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAcknowledgeUserDataCollectionRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAcknowledgeUserDataCollectionRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAcknowledgeUserDataCollectionResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAcknowledgeUserDataCollectionResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAdSenseLink' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAdSenseLink.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaApproveDisplayVideo360AdvertiserLinkProposalRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaApproveDisplayVideo360AdvertiserLinkProposalRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaApproveDisplayVideo360AdvertiserLinkProposalResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaApproveDisplayVideo360AdvertiserLinkProposalResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaArchiveAudienceRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaArchiveAudienceRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaArchiveCustomDimensionRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaArchiveCustomDimensionRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaArchiveCustomMetricRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaArchiveCustomMetricRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAttributionSettings' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAttributionSettings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAudience' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudience.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterBetweenFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterBetweenFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterInListFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterInListFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterNumericFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterNumericFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterNumericValue' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterNumericValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterStringFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceDimensionOrMetricFilterStringFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAudienceEventFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceEventFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAudienceEventTrigger' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceEventTrigger.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAudienceFilterClause' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceFilterClause.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAudienceFilterExpression' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceFilterExpression.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAudienceFilterExpressionList' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceFilterExpressionList.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAudienceSequenceFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceSequenceFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAudienceSequenceFilterAudienceSequenceStep' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceSequenceFilterAudienceSequenceStep.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaAudienceSimpleFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaAudienceSimpleFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaBatchCreateAccessBindingsRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaBatchCreateAccessBindingsRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaBatchCreateAccessBindingsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaBatchCreateAccessBindingsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaBatchDeleteAccessBindingsRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaBatchDeleteAccessBindingsRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaBatchGetAccessBindingsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaBatchGetAccessBindingsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaBatchUpdateAccessBindingsRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaBatchUpdateAccessBindingsRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaBatchUpdateAccessBindingsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaBatchUpdateAccessBindingsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaBigQueryLink' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaBigQueryLink.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaCalculatedMetric' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaCalculatedMetric.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaCancelDisplayVideo360AdvertiserLinkProposalRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaCancelDisplayVideo360AdvertiserLinkProposalRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaChangeHistoryChange' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaChangeHistoryChange.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaChangeHistoryChangeChangeHistoryResource' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaChangeHistoryChangeChangeHistoryResource.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaChangeHistoryEvent' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaChangeHistoryEvent.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaChannelGroup' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaChannelGroup.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaChannelGroupFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaChannelGroupFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaChannelGroupFilterExpression' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaChannelGroupFilterExpression.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaChannelGroupFilterExpressionList' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaChannelGroupFilterExpressionList.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaChannelGroupFilterInListFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaChannelGroupFilterInListFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaChannelGroupFilterStringFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaChannelGroupFilterStringFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaConversionEvent' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaConversionEvent.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaConversionEventDefaultConversionValue' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaConversionEventDefaultConversionValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaConversionValues' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaConversionValues.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaCreateAccessBindingRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaCreateAccessBindingRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaCreateRollupPropertyRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaCreateRollupPropertyRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaCreateRollupPropertyResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaCreateRollupPropertyResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaCustomDimension' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaCustomDimension.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaCustomMetric' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaCustomMetric.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaDataRedactionSettings' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDataRedactionSettings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaDataRetentionSettings' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDataRetentionSettings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaDataSharingSettings' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDataSharingSettings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaDataStream' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDataStream.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaDataStreamAndroidAppStreamData' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDataStreamAndroidAppStreamData.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaDataStreamIosAppStreamData' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDataStreamIosAppStreamData.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaDataStreamWebStreamData' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDataStreamWebStreamData.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaDeleteAccessBindingRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDeleteAccessBindingRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLink' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLink.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLinkProposal' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLinkProposal.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaEnhancedMeasurementSettings' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaEnhancedMeasurementSettings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaEventCreateRule' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaEventCreateRule.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaEventEditRule' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaEventEditRule.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaEventMapping' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaEventMapping.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaExpandedDataSet' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaExpandedDataSet.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaExpandedDataSetFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaExpandedDataSetFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaExpandedDataSetFilterExpression' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaExpandedDataSetFilterExpression.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaExpandedDataSetFilterExpressionList' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaExpandedDataSetFilterExpressionList.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaExpandedDataSetFilterInListFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaExpandedDataSetFilterInListFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaExpandedDataSetFilterStringFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaExpandedDataSetFilterStringFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaFirebaseLink' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaFirebaseLink.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaGlobalSiteTag' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaGlobalSiteTag.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaGoogleAdsLink' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaGoogleAdsLink.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaGoogleSignalsSettings' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaGoogleSignalsSettings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaGroupingRule' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaGroupingRule.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaKeyEvent' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaKeyEvent.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaKeyEventDefaultValue' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaKeyEventDefaultValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaLinkProposalStatusDetails' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaLinkProposalStatusDetails.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListAccessBindingsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListAccessBindingsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListAccountSummariesResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListAccountSummariesResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListAccountsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListAccountsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListAdSenseLinksResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListAdSenseLinksResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListAudiencesResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListAudiencesResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListBigQueryLinksResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListBigQueryLinksResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListCalculatedMetricsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListCalculatedMetricsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListChannelGroupsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListChannelGroupsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListConversionEventsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListConversionEventsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListCustomDimensionsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListCustomDimensionsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListCustomMetricsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListCustomMetricsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListDataStreamsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListDataStreamsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListDisplayVideo360AdvertiserLinkProposalsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListDisplayVideo360AdvertiserLinkProposalsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListDisplayVideo360AdvertiserLinksResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListDisplayVideo360AdvertiserLinksResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListEventCreateRulesResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListEventCreateRulesResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListEventEditRulesResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListEventEditRulesResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListExpandedDataSetsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListExpandedDataSetsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListFirebaseLinksResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListFirebaseLinksResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListGoogleAdsLinksResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListGoogleAdsLinksResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListKeyEventsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListKeyEventsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListMeasurementProtocolSecretsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListMeasurementProtocolSecretsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListPropertiesResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListPropertiesResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListReportingDataAnnotationsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListReportingDataAnnotationsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListRollupPropertySourceLinksResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListRollupPropertySourceLinksResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListSKAdNetworkConversionValueSchemasResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListSKAdNetworkConversionValueSchemasResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListSearchAds360LinksResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListSearchAds360LinksResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListSubpropertyEventFiltersResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListSubpropertyEventFiltersResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaListSubpropertySyncConfigsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaListSubpropertySyncConfigsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaMatchingCondition' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaMatchingCondition.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaMeasurementProtocolSecret' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaMeasurementProtocolSecret.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaNumericValue' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaNumericValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaParameterMutation' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaParameterMutation.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaPostbackWindow' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaPostbackWindow.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaProperty' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaProperty.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaPropertySummary' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaPropertySummary.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaProvisionAccountTicketRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaProvisionAccountTicketRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaProvisionAccountTicketResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaProvisionAccountTicketResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaProvisionSubpropertyRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaProvisionSubpropertyRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaProvisionSubpropertyResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaProvisionSubpropertyResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaReorderEventEditRulesRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaReorderEventEditRulesRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaReportingDataAnnotation' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaReportingDataAnnotation.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaReportingDataAnnotationDateRange' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaReportingDataAnnotationDateRange.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaReportingIdentitySettings' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaReportingIdentitySettings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaRollupPropertySourceLink' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaRollupPropertySourceLink.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaRunAccessReportRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaRunAccessReportRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaRunAccessReportResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaRunAccessReportResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaSKAdNetworkConversionValueSchema' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSKAdNetworkConversionValueSchema.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaSearchAds360Link' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSearchAds360Link.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaSearchChangeHistoryEventsRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSearchChangeHistoryEventsRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaSearchChangeHistoryEventsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSearchChangeHistoryEventsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaSubmitUserDeletionRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSubmitUserDeletionRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaSubmitUserDeletionResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSubmitUserDeletionResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaSubpropertyEventFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSubpropertyEventFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaSubpropertyEventFilterClause' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSubpropertyEventFilterClause.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaSubpropertyEventFilterCondition' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSubpropertyEventFilterCondition.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaSubpropertyEventFilterConditionStringFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSubpropertyEventFilterConditionStringFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaSubpropertyEventFilterExpression' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSubpropertyEventFilterExpression.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaSubpropertyEventFilterExpressionList' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSubpropertyEventFilterExpressionList.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaSubpropertySyncConfig' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaSubpropertySyncConfig.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleAnalyticsAdminV1alphaUpdateAccessBindingRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1alphaUpdateAccessBindingRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleProtobufEmpty' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleProtobufEmpty.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\GoogleTypeDate' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/GoogleTypeDate.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\AccountSummaries' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/AccountSummaries.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\Accounts' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/Accounts.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\AccountsAccessBindings' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/AccountsAccessBindings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\Properties' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/Properties.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesAccessBindings' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesAccessBindings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesAdSenseLinks' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesAdSenseLinks.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesAudiences' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesAudiences.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesBigQueryLinks' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesBigQueryLinks.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesCalculatedMetrics' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesCalculatedMetrics.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesChannelGroups' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesChannelGroups.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesConversionEvents' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesConversionEvents.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesCustomDimensions' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesCustomDimensions.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesCustomMetrics' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesCustomMetrics.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesDataStreams' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesDataStreams.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesDataStreamsEventCreateRules' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesDataStreamsEventCreateRules.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesDataStreamsEventEditRules' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesDataStreamsEventEditRules.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesDataStreamsMeasurementProtocolSecrets' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesDataStreamsMeasurementProtocolSecrets.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesDataStreamsSKAdNetworkConversionValueSchema' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesDataStreamsSKAdNetworkConversionValueSchema.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesDisplayVideo360AdvertiserLinkProposals' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesDisplayVideo360AdvertiserLinkProposals.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesDisplayVideo360AdvertiserLinks' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesDisplayVideo360AdvertiserLinks.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesExpandedDataSets' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesExpandedDataSets.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesFirebaseLinks' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesFirebaseLinks.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesGoogleAdsLinks' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesGoogleAdsLinks.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesKeyEvents' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesKeyEvents.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesReportingDataAnnotations' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesReportingDataAnnotations.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesRollupPropertySourceLinks' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesRollupPropertySourceLinks.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesSearchAds360Links' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesSearchAds360Links.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesSubpropertyEventFilters' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesSubpropertyEventFilters.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdminV1alpha\\Resource\\PropertiesSubpropertySyncConfigs' => $baseDir . '/google/apiclient-services-analyticsadmin.v1alpha/src/GoogleAnalyticsAdmin/Resource/PropertiesSubpropertySyncConfigs.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessBetweenFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessBetweenFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessDateRange' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessDateRange.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessDimension' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessDimension.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessDimensionHeader' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessDimensionHeader.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessDimensionValue' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessDimensionValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessFilterExpression' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessFilterExpression.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessFilterExpressionList' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessFilterExpressionList.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessInListFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessInListFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessMetric' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessMetric.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessMetricHeader' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessMetricHeader.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessMetricValue' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessMetricValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessNumericFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessNumericFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessOrderBy' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessOrderBy.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessOrderByDimensionOrderBy' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessOrderByDimensionOrderBy.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessOrderByMetricOrderBy' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessOrderByMetricOrderBy.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessQuota' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessQuota.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessQuotaStatus' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessQuotaStatus.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessRow' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessRow.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccessStringFilter' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccessStringFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccount' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccount.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAccountSummary' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAccountSummary.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAcknowledgeUserDataCollectionRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAcknowledgeUserDataCollectionRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaAcknowledgeUserDataCollectionResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaAcknowledgeUserDataCollectionResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaArchiveCustomDimensionRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaArchiveCustomDimensionRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaArchiveCustomMetricRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaArchiveCustomMetricRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaChangeHistoryChange' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaChangeHistoryChange.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaChangeHistoryChangeChangeHistoryResource' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaChangeHistoryChangeChangeHistoryResource.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaChangeHistoryEvent' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaChangeHistoryEvent.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaConversionEvent' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaConversionEvent.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaConversionEventDefaultConversionValue' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaConversionEventDefaultConversionValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaCustomDimension' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaCustomDimension.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaCustomMetric' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaCustomMetric.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaDataRetentionSettings' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaDataRetentionSettings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaDataSharingSettings' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaDataSharingSettings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaDataStream' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaDataStream.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaDataStreamAndroidAppStreamData' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaDataStreamAndroidAppStreamData.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaDataStreamIosAppStreamData' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaDataStreamIosAppStreamData.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaDataStreamWebStreamData' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaDataStreamWebStreamData.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaFirebaseLink' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaFirebaseLink.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaGoogleAdsLink' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaGoogleAdsLink.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaKeyEvent' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaKeyEvent.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaKeyEventDefaultValue' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaKeyEventDefaultValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListAccountSummariesResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListAccountSummariesResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListAccountsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListAccountsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListConversionEventsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListConversionEventsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListCustomDimensionsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListCustomDimensionsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListCustomMetricsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListCustomMetricsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListDataStreamsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListDataStreamsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListFirebaseLinksResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListFirebaseLinksResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListGoogleAdsLinksResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListGoogleAdsLinksResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListKeyEventsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListKeyEventsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListMeasurementProtocolSecretsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListMeasurementProtocolSecretsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaListPropertiesResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaListPropertiesResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaMeasurementProtocolSecret' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaMeasurementProtocolSecret.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaNumericValue' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaNumericValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaProperty' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaProperty.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaPropertySummary' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaPropertySummary.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaProvisionAccountTicketRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaProvisionAccountTicketRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaProvisionAccountTicketResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaProvisionAccountTicketResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaRunAccessReportRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaRunAccessReportRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaRunAccessReportResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaRunAccessReportResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaSearchChangeHistoryEventsRequest' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaSearchChangeHistoryEventsRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleAnalyticsAdminV1betaSearchChangeHistoryEventsResponse' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleAnalyticsAdminV1betaSearchChangeHistoryEventsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\GoogleProtobufEmpty' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/GoogleProtobufEmpty.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\Resource\\AccountSummaries' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/Resource/AccountSummaries.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\Resource\\Accounts' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/Resource/Accounts.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\Resource\\Properties' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/Resource/Properties.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesConversionEvents' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/Resource/PropertiesConversionEvents.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesCustomDimensions' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/Resource/PropertiesCustomDimensions.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesCustomMetrics' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/Resource/PropertiesCustomMetrics.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesDataStreams' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/Resource/PropertiesDataStreams.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesDataStreamsMeasurementProtocolSecrets' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/Resource/PropertiesDataStreamsMeasurementProtocolSecrets.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesFirebaseLinks' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/Resource/PropertiesFirebaseLinks.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesGoogleAdsLinks' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/Resource/PropertiesGoogleAdsLinks.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\GoogleAnalyticsAdmin\\Resource\\PropertiesKeyEvents' => $baseDir . '/google/apiclient-services-analyticsadmin.v1beta/src/GoogleAnalyticsAdmin/Resource/PropertiesKeyEvents.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\AuditRefs' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/AuditRefs.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\Bucket' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/Bucket.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\Categories' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/Categories.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\CategoryGroupV5' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/CategoryGroupV5.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\ConfigSettings' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/ConfigSettings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\Environment' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/Environment.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\I18n' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/I18n.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\LhrEntity' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/LhrEntity.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\LighthouseAuditResultV5' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/LighthouseAuditResultV5.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\LighthouseCategoryV5' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/LighthouseCategoryV5.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\LighthouseResultV5' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/LighthouseResultV5.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\MetricSavings' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/MetricSavings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\PagespeedApiLoadingExperienceV5' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/PagespeedApiLoadingExperienceV5.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\PagespeedApiPagespeedResponseV5' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/PagespeedApiPagespeedResponseV5.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\PagespeedVersion' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/PagespeedVersion.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\RendererFormattedStrings' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/RendererFormattedStrings.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\Resource\\Pagespeedapi' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/Resource/Pagespeedapi.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\RuntimeError' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/RuntimeError.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\StackPack' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/StackPack.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\Timing' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/Timing.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PagespeedInsights\\UserPageLoadMetricV5' => $baseDir . '/google/apiclient-services-pagespeedonline.v5/src/PagespeedInsights/UserPageLoadMetricV5.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Address' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Address.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\AgeRangeType' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/AgeRangeType.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\BatchCreateContactsRequest' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/BatchCreateContactsRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\BatchCreateContactsResponse' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/BatchCreateContactsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\BatchDeleteContactsRequest' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/BatchDeleteContactsRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\BatchGetContactGroupsResponse' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/BatchGetContactGroupsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\BatchUpdateContactsRequest' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/BatchUpdateContactsRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\BatchUpdateContactsResponse' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/BatchUpdateContactsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Biography' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Biography.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Birthday' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Birthday.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\BraggingRights' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/BraggingRights.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\CalendarUrl' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/CalendarUrl.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\ClientData' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/ClientData.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\ContactGroup' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/ContactGroup.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\ContactGroupMembership' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/ContactGroupMembership.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\ContactGroupMetadata' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/ContactGroupMetadata.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\ContactGroupResponse' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/ContactGroupResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\ContactToCreate' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/ContactToCreate.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\CopyOtherContactToMyContactsGroupRequest' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/CopyOtherContactToMyContactsGroupRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\CoverPhoto' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/CoverPhoto.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\CreateContactGroupRequest' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/CreateContactGroupRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Date' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Date.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\DeleteContactPhotoResponse' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/DeleteContactPhotoResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\DomainMembership' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/DomainMembership.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\EmailAddress' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/EmailAddress.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Event' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Event.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\ExternalId' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/ExternalId.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\FieldMetadata' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/FieldMetadata.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\FileAs' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/FileAs.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Gender' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Gender.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\GetPeopleResponse' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/GetPeopleResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\GroupClientData' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/GroupClientData.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\ImClient' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/ImClient.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Interest' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Interest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\ListConnectionsResponse' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/ListConnectionsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\ListContactGroupsResponse' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/ListContactGroupsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\ListDirectoryPeopleResponse' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/ListDirectoryPeopleResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\ListOtherContactsResponse' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/ListOtherContactsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Locale' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Locale.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Location' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Location.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Membership' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Membership.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\MiscKeyword' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/MiscKeyword.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\ModifyContactGroupMembersRequest' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/ModifyContactGroupMembersRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\ModifyContactGroupMembersResponse' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/ModifyContactGroupMembersResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Name' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Name.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Nickname' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Nickname.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Occupation' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Occupation.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Organization' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Organization.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\PeopleEmpty' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/PeopleEmpty.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Person' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Person.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\PersonMetadata' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/PersonMetadata.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\PersonResponse' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/PersonResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\PhoneNumber' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/PhoneNumber.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Photo' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Photo.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\ProfileMetadata' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/ProfileMetadata.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Relation' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Relation.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\RelationshipInterest' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/RelationshipInterest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\RelationshipStatus' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/RelationshipStatus.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Residence' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Residence.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Resource\\ContactGroups' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Resource/ContactGroups.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Resource\\ContactGroupsMembers' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Resource/ContactGroupsMembers.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Resource\\OtherContacts' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Resource/OtherContacts.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Resource\\People' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Resource/People.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Resource\\PeopleConnections' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Resource/PeopleConnections.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\SearchDirectoryPeopleResponse' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/SearchDirectoryPeopleResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\SearchResponse' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/SearchResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\SearchResult' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/SearchResult.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\SipAddress' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/SipAddress.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Skill' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Skill.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Source' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Source.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Status' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Status.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Tagline' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Tagline.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\UpdateContactGroupRequest' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/UpdateContactGroupRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\UpdateContactPhotoRequest' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/UpdateContactPhotoRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\UpdateContactPhotoResponse' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/UpdateContactPhotoResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\Url' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/Url.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\PeopleService\\UserDefined' => $baseDir . '/google/apiclient-services-people.v1/src/PeopleService/UserDefined.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Resource' => $baseDir . '/google/apiclient/src/Service/Resource.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\AmpInspectionResult' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/AmpInspectionResult.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\AmpIssue' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/AmpIssue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\ApiDataRow' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/ApiDataRow.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\ApiDimensionFilter' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/ApiDimensionFilter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\ApiDimensionFilterGroup' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/ApiDimensionFilterGroup.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\BlockedResource' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/BlockedResource.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\DetectedItems' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/DetectedItems.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\Image' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/Image.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\IndexStatusInspectionResult' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/IndexStatusInspectionResult.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\InspectUrlIndexRequest' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/InspectUrlIndexRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\InspectUrlIndexResponse' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/InspectUrlIndexResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\Item' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/Item.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\Metadata' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/Metadata.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\MobileFriendlyIssue' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/MobileFriendlyIssue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\MobileUsabilityInspectionResult' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/MobileUsabilityInspectionResult.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\MobileUsabilityIssue' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/MobileUsabilityIssue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\ResourceIssue' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/ResourceIssue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\Resource\\Searchanalytics' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/Resource/Searchanalytics.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\Resource\\Sitemaps' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/Resource/Sitemaps.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\Resource\\Sites' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/Resource/Sites.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\Resource\\UrlInspection' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/Resource/UrlInspection.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\Resource\\UrlInspectionIndex' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/Resource/UrlInspectionIndex.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\Resource\\UrlTestingTools' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/Resource/UrlTestingTools.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\Resource\\UrlTestingToolsMobileFriendlyTest' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/Resource/UrlTestingToolsMobileFriendlyTest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\RichResultsInspectionResult' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/RichResultsInspectionResult.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\RichResultsIssue' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/RichResultsIssue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\RunMobileFriendlyTestRequest' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/RunMobileFriendlyTestRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\RunMobileFriendlyTestResponse' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/RunMobileFriendlyTestResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\SearchAnalyticsQueryRequest' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/SearchAnalyticsQueryRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\SearchAnalyticsQueryResponse' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/SearchAnalyticsQueryResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\SitemapsListResponse' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/SitemapsListResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\SitesListResponse' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/SitesListResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\TestStatus' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/TestStatus.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\UrlInspectionResult' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/UrlInspectionResult.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\WmxSite' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/WmxSite.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\WmxSitemap' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/WmxSitemap.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SearchConsole\\WmxSitemapContent' => $baseDir . '/google/apiclient-services-searchconsole.v1/src/SearchConsole/WmxSitemapContent.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SiteVerification' => $baseDir . '/google/apiclient-services-siteverification.v1/src/SiteVerification.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SiteVerification\\Resource\\WebResource' => $baseDir . '/google/apiclient-services-siteverification.v1/src/SiteVerification/Resource/WebResource.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SiteVerification\\SiteVerificationWebResourceGettokenRequest' => $baseDir . '/google/apiclient-services-siteverification.v1/src/SiteVerification/SiteVerificationWebResourceGettokenRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SiteVerification\\SiteVerificationWebResourceGettokenRequestSite' => $baseDir . '/google/apiclient-services-siteverification.v1/src/SiteVerification/SiteVerificationWebResourceGettokenRequestSite.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SiteVerification\\SiteVerificationWebResourceGettokenResponse' => $baseDir . '/google/apiclient-services-siteverification.v1/src/SiteVerification/SiteVerificationWebResourceGettokenResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SiteVerification\\SiteVerificationWebResourceListResponse' => $baseDir . '/google/apiclient-services-siteverification.v1/src/SiteVerification/SiteVerificationWebResourceListResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SiteVerification\\SiteVerificationWebResourceResource' => $baseDir . '/google/apiclient-services-siteverification.v1/src/SiteVerification/SiteVerificationWebResourceResource.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SiteVerification\\SiteVerificationWebResourceResourceSite' => $baseDir . '/google/apiclient-services-siteverification.v1/src/SiteVerification/SiteVerificationWebResourceResourceSite.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\AmountDetails' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/AmountDetails.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\CancelUserEntitlementsPlanRequest' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/CancelUserEntitlementsPlanRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\CanceledDetails' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/CanceledDetails.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\CheckFreeAccessResponse' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/CheckFreeAccessResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\ContentPolicyStatus' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/ContentPolicyStatus.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\Entitlement' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/Entitlement.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\ListEntitlementsResponse' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/ListEntitlementsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\ListOrdersResponse' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/ListOrdersResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\ListPublicationsResponse' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/ListPublicationsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\ListUserEntitlementsPlansResponse' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/ListUserEntitlementsPlansResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\MerchantRevenueData' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/MerchantRevenueData.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\Money' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/Money.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\Order' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/Order.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\PaymentAddress' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/PaymentAddress.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\PaymentOptions' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/PaymentOptions.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\PlanEntitlement' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/PlanEntitlement.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\PriceDetails' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/PriceDetails.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\Product' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/Product.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\Publication' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/Publication.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\PurchaseInfo' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/PurchaseInfo.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\Reader' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/Reader.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\RecurrenceDetails' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/RecurrenceDetails.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\RecurrenceDuration' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/RecurrenceDuration.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\RecurrencePeriod' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/RecurrencePeriod.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\RecurrenceTerms' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/RecurrenceTerms.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\RecurringPlanDetails' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/RecurringPlanDetails.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\RefundOrderRequest' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/RefundOrderRequest.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\Resource\\Publications' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/Resource/Publications.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\Resource\\PublicationsEntitlements' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/Resource/PublicationsEntitlements.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\Resource\\PublicationsReaders' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/Resource/PublicationsReaders.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\Resource\\PublicationsReadersEntitlementsplans' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/Resource/PublicationsReadersEntitlementsplans.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\Resource\\PublicationsReadersOrders' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/Resource/PublicationsReadersOrders.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\StateDetails' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/StateDetails.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\SuspendedDetails' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/SuspendedDetails.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\TaxDetails' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/TaxDetails.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\UserEntitlementsPlan' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/UserEntitlementsPlan.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\SubscribewithGoogle\\WaitingToRecurDetails' => $baseDir . '/google/apiclient-services-subscribewithgoogle/src/SubscribewithGoogle/WaitingToRecurDetails.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Account' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Account.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\AccountAccess' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/AccountAccess.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\AccountFeatures' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/AccountFeatures.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\BuiltInVariable' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/BuiltInVariable.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\BulkUpdateWorkspaceResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/BulkUpdateWorkspaceResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Client' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Client.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Condition' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Condition.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Container' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Container.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ContainerAccess' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ContainerAccess.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ContainerFeatures' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ContainerFeatures.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ContainerVersion' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ContainerVersion.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ContainerVersionHeader' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ContainerVersionHeader.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\CreateBuiltInVariableResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/CreateBuiltInVariableResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\CreateContainerVersionRequestVersionOptions' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/CreateContainerVersionRequestVersionOptions.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\CreateContainerVersionResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/CreateContainerVersionResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\CustomTemplate' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/CustomTemplate.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Destination' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Destination.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Entity' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Entity.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Environment' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Environment.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Folder' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Folder.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\FolderEntities' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/FolderEntities.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\GalleryReference' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/GalleryReference.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\GetContainerSnippetResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/GetContainerSnippetResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\GetWorkspaceStatusResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/GetWorkspaceStatusResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\GtagConfig' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/GtagConfig.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListAccountsResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListAccountsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListClientsResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListClientsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListContainerVersionsResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListContainerVersionsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListContainersResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListContainersResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListDestinationsResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListDestinationsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListEnabledBuiltInVariablesResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListEnabledBuiltInVariablesResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListEnvironmentsResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListEnvironmentsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListFoldersResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListFoldersResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListGtagConfigResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListGtagConfigResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListTagsResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListTagsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListTemplatesResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListTemplatesResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListTransformationsResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListTransformationsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListTriggersResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListTriggersResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListUserPermissionsResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListUserPermissionsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListVariablesResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListVariablesResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListWorkspacesResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListWorkspacesResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ListZonesResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ListZonesResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\MergeConflict' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/MergeConflict.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Parameter' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Parameter.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ProposedChange' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ProposedChange.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\PublishContainerVersionResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/PublishContainerVersionResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\QuickPreviewResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/QuickPreviewResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\Accounts' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/Accounts.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainers' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainers.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainersDestinations' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainersDestinations.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainersEnvironments' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainersEnvironments.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainersVersionHeaders' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainersVersionHeaders.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainersVersions' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainersVersions.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspaces' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainersWorkspaces.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesBuiltInVariables' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainersWorkspacesBuiltInVariables.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesClients' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainersWorkspacesClients.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesFolders' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainersWorkspacesFolders.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesGtagConfig' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainersWorkspacesGtagConfig.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesTags' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainersWorkspacesTags.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesTemplates' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainersWorkspacesTemplates.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesTransformations' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainersWorkspacesTransformations.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesTriggers' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainersWorkspacesTriggers.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesVariables' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainersWorkspacesVariables.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsContainersWorkspacesZones' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsContainersWorkspacesZones.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Resource\\AccountsUserPermissions' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Resource/AccountsUserPermissions.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\RevertBuiltInVariableResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/RevertBuiltInVariableResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\RevertClientResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/RevertClientResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\RevertFolderResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/RevertFolderResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\RevertTagResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/RevertTagResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\RevertTemplateResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/RevertTemplateResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\RevertTransformationResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/RevertTransformationResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\RevertTriggerResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/RevertTriggerResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\RevertVariableResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/RevertVariableResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\RevertZoneResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/RevertZoneResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\SetupTag' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/SetupTag.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\SyncStatus' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/SyncStatus.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\SyncWorkspaceResponse' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/SyncWorkspaceResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Tag' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Tag.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\TagConsentSetting' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/TagConsentSetting.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\TeardownTag' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/TeardownTag.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Transformation' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Transformation.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Trigger' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Trigger.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\UserPermission' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/UserPermission.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Variable' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Variable.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\VariableFormatValue' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/VariableFormatValue.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Workspace' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Workspace.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\Zone' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/Zone.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ZoneBoundary' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ZoneBoundary.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ZoneChildContainer' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ZoneChildContainer.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\TagManager\\ZoneTypeRestriction' => $baseDir . '/google/apiclient-services-tagmanager.v2/src/TagManager/ZoneTypeRestriction.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Webcontentpublisher' => $baseDir . '/google/apiclient-services-webcontentpublisher/src/WebContentPublisher.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Webcontentpublisher\\CheckFreeAccessResponse' => $baseDir . '/google/apiclient-services-webcontentpublisher/src/WebContentPublisher/CheckFreeAccessResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Webcontentpublisher\\ContentPolicyStatus' => $baseDir . '/google/apiclient-services-webcontentpublisher/src/WebContentPublisher/ContentPolicyStatus.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Webcontentpublisher\\Cta' => $baseDir . '/google/apiclient-services-webcontentpublisher/src/WebContentPublisher/Cta.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Webcontentpublisher\\DomainProperty' => $baseDir . '/google/apiclient-services-webcontentpublisher/src/WebContentPublisher/DomainProperty.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Webcontentpublisher\\ListCtasResponse' => $baseDir . '/google/apiclient-services-webcontentpublisher/src/WebContentPublisher/ListCtasResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Webcontentpublisher\\ListPublicationsResponse' => $baseDir . '/google/apiclient-services-webcontentpublisher/src/WebContentPublisher/ListPublicationsResponse.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Webcontentpublisher\\NewsletterConfig' => $baseDir . '/google/apiclient-services-webcontentpublisher/src/WebContentPublisher/NewsletterConfig.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Webcontentpublisher\\Publication' => $baseDir . '/google/apiclient-services-webcontentpublisher/src/WebContentPublisher/Publication.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Webcontentpublisher\\Resource\\OrganizationsPublications' => $baseDir . '/google/apiclient-services-webcontentpublisher/src/WebContentPublisher/Resource/OrganizationsPublications.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Webcontentpublisher\\Resource\\OrganizationsPublicationsCtas' => $baseDir . '/google/apiclient-services-webcontentpublisher/src/WebContentPublisher/Resource/OrganizationsPublicationsCtas.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Webcontentpublisher\\Resource\\Publications' => $baseDir . '/google/apiclient-services-webcontentpublisher/src/WebContentPublisher/Resource/Publications.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Webcontentpublisher\\RrmProduct' => $baseDir . '/google/apiclient-services-webcontentpublisher/src/WebContentPublisher/RrmProduct.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Webcontentpublisher\\SlProduct' => $baseDir . '/google/apiclient-services-webcontentpublisher/src/WebContentPublisher/SlProduct.php',
    'Google\\Site_Kit_Dependencies\\Google\\Service\\Webcontentpublisher\\TosAcceptance' => $baseDir . '/google/apiclient-services-webcontentpublisher/src/WebContentPublisher/TosAcceptance.php',
    'Google\\Site_Kit_Dependencies\\Google\\Task\\Composer' => $baseDir . '/google/apiclient/src/Task/Composer.php',
    'Google\\Site_Kit_Dependencies\\Google\\Task\\Exception' => $baseDir . '/google/apiclient/src/Task/Exception.php',
    'Google\\Site_Kit_Dependencies\\Google\\Task\\Retryable' => $baseDir . '/google/apiclient/src/Task/Retryable.php',
    'Google\\Site_Kit_Dependencies\\Google\\Task\\Runner' => $baseDir . '/google/apiclient/src/Task/Runner.php',
    'Google\\Site_Kit_Dependencies\\Google\\Utils\\UriTemplate' => $baseDir . '/google/apiclient/src/Utils/UriTemplate.php',
    'Google\\Site_Kit_Dependencies\\Google_AccessToken_Revoke' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_AccessToken_Verify' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_AuthHandler_AuthHandlerFactory' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_AuthHandler_Guzzle6AuthHandler' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_AuthHandler_Guzzle7AuthHandler' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_Client' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_Collection' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_Exception' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_Http_Batch' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_Http_MediaFileUpload' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_Http_REST' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_Model' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_Service' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_Service_Exception' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_Service_Resource' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_Task_Composer' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_Task_Exception' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_Task_Retryable' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_Task_Runner' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\Google_Utils_UriTemplate' => $baseDir . '/google/apiclient/src/aliases.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\BodySummarizer' => $baseDir . '/guzzlehttp/guzzle/src/BodySummarizer.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\BodySummarizerInterface' => $baseDir . '/guzzlehttp/guzzle/src/BodySummarizerInterface.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Client' => $baseDir . '/guzzlehttp/guzzle/src/Client.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\ClientInterface' => $baseDir . '/guzzlehttp/guzzle/src/ClientInterface.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\ClientTrait' => $baseDir . '/guzzlehttp/guzzle/src/ClientTrait.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Cookie\\CookieJar' => $baseDir . '/guzzlehttp/guzzle/src/Cookie/CookieJar.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Cookie\\CookieJarInterface' => $baseDir . '/guzzlehttp/guzzle/src/Cookie/CookieJarInterface.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Cookie\\FileCookieJar' => $baseDir . '/guzzlehttp/guzzle/src/Cookie/FileCookieJar.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Cookie\\SessionCookieJar' => $baseDir . '/guzzlehttp/guzzle/src/Cookie/SessionCookieJar.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Cookie\\SetCookie' => $baseDir . '/guzzlehttp/guzzle/src/Cookie/SetCookie.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Exception\\BadResponseException' => $baseDir . '/guzzlehttp/guzzle/src/Exception/BadResponseException.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Exception\\ClientException' => $baseDir . '/guzzlehttp/guzzle/src/Exception/ClientException.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Exception\\ConnectException' => $baseDir . '/guzzlehttp/guzzle/src/Exception/ConnectException.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Exception\\GuzzleException' => $baseDir . '/guzzlehttp/guzzle/src/Exception/GuzzleException.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Exception\\InvalidArgumentException' => $baseDir . '/guzzlehttp/guzzle/src/Exception/InvalidArgumentException.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Exception\\RequestException' => $baseDir . '/guzzlehttp/guzzle/src/Exception/RequestException.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Exception\\ServerException' => $baseDir . '/guzzlehttp/guzzle/src/Exception/ServerException.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Exception\\TooManyRedirectsException' => $baseDir . '/guzzlehttp/guzzle/src/Exception/TooManyRedirectsException.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Exception\\TransferException' => $baseDir . '/guzzlehttp/guzzle/src/Exception/TransferException.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\HandlerStack' => $baseDir . '/guzzlehttp/guzzle/src/HandlerStack.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Handler\\CurlFactory' => $baseDir . '/guzzlehttp/guzzle/src/Handler/CurlFactory.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Handler\\CurlFactoryInterface' => $baseDir . '/guzzlehttp/guzzle/src/Handler/CurlFactoryInterface.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Handler\\CurlHandler' => $baseDir . '/guzzlehttp/guzzle/src/Handler/CurlHandler.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Handler\\CurlMultiHandler' => $baseDir . '/guzzlehttp/guzzle/src/Handler/CurlMultiHandler.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Handler\\EasyHandle' => $baseDir . '/guzzlehttp/guzzle/src/Handler/EasyHandle.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Handler\\HeaderProcessor' => $baseDir . '/guzzlehttp/guzzle/src/Handler/HeaderProcessor.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Handler\\MockHandler' => $baseDir . '/guzzlehttp/guzzle/src/Handler/MockHandler.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Handler\\Proxy' => $baseDir . '/guzzlehttp/guzzle/src/Handler/Proxy.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Handler\\StreamHandler' => $baseDir . '/guzzlehttp/guzzle/src/Handler/StreamHandler.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\MessageFormatter' => $baseDir . '/guzzlehttp/guzzle/src/MessageFormatter.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\MessageFormatterInterface' => $baseDir . '/guzzlehttp/guzzle/src/MessageFormatterInterface.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Middleware' => $baseDir . '/guzzlehttp/guzzle/src/Middleware.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Pool' => $baseDir . '/guzzlehttp/guzzle/src/Pool.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\PrepareBodyMiddleware' => $baseDir . '/guzzlehttp/guzzle/src/PrepareBodyMiddleware.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\AggregateException' => $baseDir . '/guzzlehttp/promises/src/AggregateException.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\CancellationException' => $baseDir . '/guzzlehttp/promises/src/CancellationException.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\Coroutine' => $baseDir . '/guzzlehttp/promises/src/Coroutine.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\Create' => $baseDir . '/guzzlehttp/promises/src/Create.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\Each' => $baseDir . '/guzzlehttp/promises/src/Each.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\EachPromise' => $baseDir . '/guzzlehttp/promises/src/EachPromise.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\FulfilledPromise' => $baseDir . '/guzzlehttp/promises/src/FulfilledPromise.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\Is' => $baseDir . '/guzzlehttp/promises/src/Is.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\Promise' => $baseDir . '/guzzlehttp/promises/src/Promise.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\PromiseInterface' => $baseDir . '/guzzlehttp/promises/src/PromiseInterface.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\PromisorInterface' => $baseDir . '/guzzlehttp/promises/src/PromisorInterface.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\RejectedPromise' => $baseDir . '/guzzlehttp/promises/src/RejectedPromise.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\RejectionException' => $baseDir . '/guzzlehttp/promises/src/RejectionException.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\TaskQueue' => $baseDir . '/guzzlehttp/promises/src/TaskQueue.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\TaskQueueInterface' => $baseDir . '/guzzlehttp/promises/src/TaskQueueInterface.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Promise\\Utils' => $baseDir . '/guzzlehttp/promises/src/Utils.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\AppendStream' => $baseDir . '/guzzlehttp/psr7/src/AppendStream.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\BufferStream' => $baseDir . '/guzzlehttp/psr7/src/BufferStream.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\CachingStream' => $baseDir . '/guzzlehttp/psr7/src/CachingStream.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\DroppingStream' => $baseDir . '/guzzlehttp/psr7/src/DroppingStream.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\Exception\\MalformedUriException' => $baseDir . '/guzzlehttp/psr7/src/Exception/MalformedUriException.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\FnStream' => $baseDir . '/guzzlehttp/psr7/src/FnStream.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\Header' => $baseDir . '/guzzlehttp/psr7/src/Header.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\HttpFactory' => $baseDir . '/guzzlehttp/psr7/src/HttpFactory.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\InflateStream' => $baseDir . '/guzzlehttp/psr7/src/InflateStream.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\LazyOpenStream' => $baseDir . '/guzzlehttp/psr7/src/LazyOpenStream.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\LimitStream' => $baseDir . '/guzzlehttp/psr7/src/LimitStream.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\Message' => $baseDir . '/guzzlehttp/psr7/src/Message.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\MessageTrait' => $baseDir . '/guzzlehttp/psr7/src/MessageTrait.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\MimeType' => $baseDir . '/guzzlehttp/psr7/src/MimeType.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\MultipartStream' => $baseDir . '/guzzlehttp/psr7/src/MultipartStream.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\NoSeekStream' => $baseDir . '/guzzlehttp/psr7/src/NoSeekStream.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\PumpStream' => $baseDir . '/guzzlehttp/psr7/src/PumpStream.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\Query' => $baseDir . '/guzzlehttp/psr7/src/Query.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\Request' => $baseDir . '/guzzlehttp/psr7/src/Request.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\Response' => $baseDir . '/guzzlehttp/psr7/src/Response.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\Rfc7230' => $baseDir . '/guzzlehttp/psr7/src/Rfc7230.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\ServerRequest' => $baseDir . '/guzzlehttp/psr7/src/ServerRequest.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\Stream' => $baseDir . '/guzzlehttp/psr7/src/Stream.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\StreamDecoratorTrait' => $baseDir . '/guzzlehttp/psr7/src/StreamDecoratorTrait.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\StreamWrapper' => $baseDir . '/guzzlehttp/psr7/src/StreamWrapper.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\UploadedFile' => $baseDir . '/guzzlehttp/psr7/src/UploadedFile.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\Uri' => $baseDir . '/guzzlehttp/psr7/src/Uri.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\UriComparator' => $baseDir . '/guzzlehttp/psr7/src/UriComparator.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\UriNormalizer' => $baseDir . '/guzzlehttp/psr7/src/UriNormalizer.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\UriResolver' => $baseDir . '/guzzlehttp/psr7/src/UriResolver.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Psr7\\Utils' => $baseDir . '/guzzlehttp/psr7/src/Utils.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\RedirectMiddleware' => $baseDir . '/guzzlehttp/guzzle/src/RedirectMiddleware.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\RequestOptions' => $baseDir . '/guzzlehttp/guzzle/src/RequestOptions.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\RetryMiddleware' => $baseDir . '/guzzlehttp/guzzle/src/RetryMiddleware.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\TransferStats' => $baseDir . '/guzzlehttp/guzzle/src/TransferStats.php',
    'Google\\Site_Kit_Dependencies\\GuzzleHttp\\Utils' => $baseDir . '/guzzlehttp/guzzle/src/Utils.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Attribute\\AsMonologProcessor' => $baseDir . '/monolog/monolog/src/Monolog/Attribute/AsMonologProcessor.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\DateTimeImmutable' => $baseDir . '/monolog/monolog/src/Monolog/DateTimeImmutable.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\ErrorHandler' => $baseDir . '/monolog/monolog/src/Monolog/ErrorHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\ChromePHPFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/ChromePHPFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\ElasticaFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/ElasticaFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\ElasticsearchFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/ElasticsearchFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\FlowdockFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/FlowdockFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\FluentdFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/FluentdFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\FormatterInterface' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/FormatterInterface.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\GelfMessageFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/GelfMessageFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\GoogleCloudLoggingFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/GoogleCloudLoggingFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\HtmlFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/HtmlFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\JsonFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/JsonFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\LineFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/LineFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\LogglyFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/LogglyFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\LogmaticFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/LogmaticFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\LogstashFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/LogstashFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\MongoDBFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/MongoDBFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\NormalizerFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/NormalizerFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\ScalarFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/ScalarFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Formatter\\WildfireFormatter' => $baseDir . '/monolog/monolog/src/Monolog/Formatter/WildfireFormatter.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\AbstractHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/AbstractHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\AbstractProcessingHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/AbstractProcessingHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\AbstractSyslogHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/AbstractSyslogHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\AmqpHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/AmqpHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\BrowserConsoleHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/BrowserConsoleHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\BufferHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/BufferHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\ChromePHPHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/ChromePHPHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\CouchDBHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/CouchDBHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\CubeHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/CubeHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\Curl\\Util' => $baseDir . '/monolog/monolog/src/Monolog/Handler/Curl/Util.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\DeduplicationHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/DeduplicationHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\DoctrineCouchDBHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/DoctrineCouchDBHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\DynamoDbHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/DynamoDbHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\ElasticaHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/ElasticaHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\ElasticsearchHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/ElasticsearchHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\ErrorLogHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/ErrorLogHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\FallbackGroupHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/FallbackGroupHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\FilterHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/FilterHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\FingersCrossedHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/FingersCrossedHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\FingersCrossed\\ActivationStrategyInterface' => $baseDir . '/monolog/monolog/src/Monolog/Handler/FingersCrossed/ActivationStrategyInterface.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\FingersCrossed\\ChannelLevelActivationStrategy' => $baseDir . '/monolog/monolog/src/Monolog/Handler/FingersCrossed/ChannelLevelActivationStrategy.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\FingersCrossed\\ErrorLevelActivationStrategy' => $baseDir . '/monolog/monolog/src/Monolog/Handler/FingersCrossed/ErrorLevelActivationStrategy.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\FirePHPHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/FirePHPHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\FleepHookHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/FleepHookHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\FlowdockHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/FlowdockHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\FormattableHandlerInterface' => $baseDir . '/monolog/monolog/src/Monolog/Handler/FormattableHandlerInterface.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\FormattableHandlerTrait' => $baseDir . '/monolog/monolog/src/Monolog/Handler/FormattableHandlerTrait.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\GelfHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/GelfHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\GroupHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/GroupHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\Handler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/Handler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\HandlerInterface' => $baseDir . '/monolog/monolog/src/Monolog/Handler/HandlerInterface.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\HandlerWrapper' => $baseDir . '/monolog/monolog/src/Monolog/Handler/HandlerWrapper.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\IFTTTHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/IFTTTHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\InsightOpsHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/InsightOpsHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\LogEntriesHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/LogEntriesHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\LogglyHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/LogglyHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\LogmaticHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/LogmaticHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\MailHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/MailHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\MandrillHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/MandrillHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\MissingExtensionException' => $baseDir . '/monolog/monolog/src/Monolog/Handler/MissingExtensionException.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\MongoDBHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/MongoDBHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\NativeMailerHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/NativeMailerHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\NewRelicHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/NewRelicHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\NoopHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/NoopHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\NullHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/NullHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\OverflowHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/OverflowHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\PHPConsoleHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/PHPConsoleHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\ProcessHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/ProcessHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\ProcessableHandlerInterface' => $baseDir . '/monolog/monolog/src/Monolog/Handler/ProcessableHandlerInterface.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\ProcessableHandlerTrait' => $baseDir . '/monolog/monolog/src/Monolog/Handler/ProcessableHandlerTrait.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\PsrHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/PsrHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\PushoverHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/PushoverHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\RedisHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/RedisHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\RedisPubSubHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/RedisPubSubHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\RollbarHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/RollbarHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\RotatingFileHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/RotatingFileHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\SamplingHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/SamplingHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\SendGridHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/SendGridHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\SlackHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/SlackHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\SlackWebhookHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/SlackWebhookHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\Slack\\SlackRecord' => $baseDir . '/monolog/monolog/src/Monolog/Handler/Slack/SlackRecord.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\SocketHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/SocketHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\SqsHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/SqsHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\StreamHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/StreamHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\SwiftMailerHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/SwiftMailerHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\SymfonyMailerHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/SymfonyMailerHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\SyslogHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/SyslogHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\SyslogUdpHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/SyslogUdpHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\SyslogUdp\\UdpSocket' => $baseDir . '/monolog/monolog/src/Monolog/Handler/SyslogUdp/UdpSocket.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\TelegramBotHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/TelegramBotHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\TestHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/TestHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\WebRequestRecognizerTrait' => $baseDir . '/monolog/monolog/src/Monolog/Handler/WebRequestRecognizerTrait.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\WhatFailureGroupHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/WhatFailureGroupHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Handler\\ZendMonitorHandler' => $baseDir . '/monolog/monolog/src/Monolog/Handler/ZendMonitorHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\LogRecord' => $baseDir . '/monolog/monolog/src/Monolog/LogRecord.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Logger' => $baseDir . '/monolog/monolog/src/Monolog/Logger.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Processor\\GitProcessor' => $baseDir . '/monolog/monolog/src/Monolog/Processor/GitProcessor.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Processor\\HostnameProcessor' => $baseDir . '/monolog/monolog/src/Monolog/Processor/HostnameProcessor.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Processor\\IntrospectionProcessor' => $baseDir . '/monolog/monolog/src/Monolog/Processor/IntrospectionProcessor.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Processor\\MemoryPeakUsageProcessor' => $baseDir . '/monolog/monolog/src/Monolog/Processor/MemoryPeakUsageProcessor.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Processor\\MemoryProcessor' => $baseDir . '/monolog/monolog/src/Monolog/Processor/MemoryProcessor.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Processor\\MemoryUsageProcessor' => $baseDir . '/monolog/monolog/src/Monolog/Processor/MemoryUsageProcessor.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Processor\\MercurialProcessor' => $baseDir . '/monolog/monolog/src/Monolog/Processor/MercurialProcessor.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Processor\\ProcessIdProcessor' => $baseDir . '/monolog/monolog/src/Monolog/Processor/ProcessIdProcessor.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Processor\\ProcessorInterface' => $baseDir . '/monolog/monolog/src/Monolog/Processor/ProcessorInterface.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Processor\\PsrLogMessageProcessor' => $baseDir . '/monolog/monolog/src/Monolog/Processor/PsrLogMessageProcessor.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Processor\\TagProcessor' => $baseDir . '/monolog/monolog/src/Monolog/Processor/TagProcessor.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Processor\\UidProcessor' => $baseDir . '/monolog/monolog/src/Monolog/Processor/UidProcessor.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Processor\\WebProcessor' => $baseDir . '/monolog/monolog/src/Monolog/Processor/WebProcessor.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Registry' => $baseDir . '/monolog/monolog/src/Monolog/Registry.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\ResettableInterface' => $baseDir . '/monolog/monolog/src/Monolog/ResettableInterface.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\SignalHandler' => $baseDir . '/monolog/monolog/src/Monolog/SignalHandler.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Test\\TestCase' => $baseDir . '/monolog/monolog/src/Monolog/Test/TestCase.php',
    'Google\\Site_Kit_Dependencies\\Monolog\\Utils' => $baseDir . '/monolog/monolog/src/Monolog/Utils.php',
    'Google\\Site_Kit_Dependencies\\Normalizer' => $baseDir . '/symfony/polyfill-intl-normalizer/Resources/stubs/Normalizer.php',
    'Google\\Site_Kit_Dependencies\\ParagonIE\\ConstantTime\\Base32' => $baseDir . '/paragonie/constant_time_encoding/src/Base32.php',
    'Google\\Site_Kit_Dependencies\\ParagonIE\\ConstantTime\\Base32Hex' => $baseDir . '/paragonie/constant_time_encoding/src/Base32Hex.php',
    'Google\\Site_Kit_Dependencies\\ParagonIE\\ConstantTime\\Base64' => $baseDir . '/paragonie/constant_time_encoding/src/Base64.php',
    'Google\\Site_Kit_Dependencies\\ParagonIE\\ConstantTime\\Base64DotSlash' => $baseDir . '/paragonie/constant_time_encoding/src/Base64DotSlash.php',
    'Google\\Site_Kit_Dependencies\\ParagonIE\\ConstantTime\\Base64DotSlashOrdered' => $baseDir . '/paragonie/constant_time_encoding/src/Base64DotSlashOrdered.php',
    'Google\\Site_Kit_Dependencies\\ParagonIE\\ConstantTime\\Base64UrlSafe' => $baseDir . '/paragonie/constant_time_encoding/src/Base64UrlSafe.php',
    'Google\\Site_Kit_Dependencies\\ParagonIE\\ConstantTime\\Binary' => $baseDir . '/paragonie/constant_time_encoding/src/Binary.php',
    'Google\\Site_Kit_Dependencies\\ParagonIE\\ConstantTime\\EncoderInterface' => $baseDir . '/paragonie/constant_time_encoding/src/EncoderInterface.php',
    'Google\\Site_Kit_Dependencies\\ParagonIE\\ConstantTime\\Encoding' => $baseDir . '/paragonie/constant_time_encoding/src/Encoding.php',
    'Google\\Site_Kit_Dependencies\\ParagonIE\\ConstantTime\\Hex' => $baseDir . '/paragonie/constant_time_encoding/src/Hex.php',
    'Google\\Site_Kit_Dependencies\\ParagonIE\\ConstantTime\\RFC4648' => $baseDir . '/paragonie/constant_time_encoding/src/RFC4648.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Cache\\CacheException' => $baseDir . '/psr/cache/src/CacheException.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Cache\\CacheItemInterface' => $baseDir . '/psr/cache/src/CacheItemInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Cache\\CacheItemPoolInterface' => $baseDir . '/psr/cache/src/CacheItemPoolInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Cache\\InvalidArgumentException' => $baseDir . '/psr/cache/src/InvalidArgumentException.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Client\\ClientExceptionInterface' => $baseDir . '/psr/http-client/src/ClientExceptionInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Client\\ClientInterface' => $baseDir . '/psr/http-client/src/ClientInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Client\\NetworkExceptionInterface' => $baseDir . '/psr/http-client/src/NetworkExceptionInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Client\\RequestExceptionInterface' => $baseDir . '/psr/http-client/src/RequestExceptionInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Message\\MessageInterface' => $baseDir . '/psr/http-message/src/MessageInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Message\\RequestFactoryInterface' => $baseDir . '/psr/http-factory/src/RequestFactoryInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Message\\RequestInterface' => $baseDir . '/psr/http-message/src/RequestInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Message\\ResponseFactoryInterface' => $baseDir . '/psr/http-factory/src/ResponseFactoryInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Message\\ResponseInterface' => $baseDir . '/psr/http-message/src/ResponseInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Message\\ServerRequestFactoryInterface' => $baseDir . '/psr/http-factory/src/ServerRequestFactoryInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Message\\ServerRequestInterface' => $baseDir . '/psr/http-message/src/ServerRequestInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Message\\StreamFactoryInterface' => $baseDir . '/psr/http-factory/src/StreamFactoryInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Message\\StreamInterface' => $baseDir . '/psr/http-message/src/StreamInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Message\\UploadedFileFactoryInterface' => $baseDir . '/psr/http-factory/src/UploadedFileFactoryInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Message\\UploadedFileInterface' => $baseDir . '/psr/http-message/src/UploadedFileInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Message\\UriFactoryInterface' => $baseDir . '/psr/http-factory/src/UriFactoryInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Http\\Message\\UriInterface' => $baseDir . '/psr/http-message/src/UriInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Log\\AbstractLogger' => $baseDir . '/psr/log/Psr/Log/AbstractLogger.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Log\\InvalidArgumentException' => $baseDir . '/psr/log/Psr/Log/InvalidArgumentException.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Log\\LogLevel' => $baseDir . '/psr/log/Psr/Log/LogLevel.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Log\\LoggerAwareInterface' => $baseDir . '/psr/log/Psr/Log/LoggerAwareInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Log\\LoggerAwareTrait' => $baseDir . '/psr/log/Psr/Log/LoggerAwareTrait.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Log\\LoggerInterface' => $baseDir . '/psr/log/Psr/Log/LoggerInterface.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Log\\LoggerTrait' => $baseDir . '/psr/log/Psr/Log/LoggerTrait.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Log\\NullLogger' => $baseDir . '/psr/log/Psr/Log/NullLogger.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Log\\Test\\DummyTest' => $baseDir . '/psr/log/Psr/Log/Test/DummyTest.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Log\\Test\\LoggerInterfaceTest' => $baseDir . '/psr/log/Psr/Log/Test/LoggerInterfaceTest.php',
    'Google\\Site_Kit_Dependencies\\Psr\\Log\\Test\\TestLogger' => $baseDir . '/psr/log/Psr/Log/Test/TestLogger.php',
    'Google\\Site_Kit_Dependencies\\Symfony\\Polyfill\\Intl\\Idn\\Idn' => $baseDir . '/symfony/polyfill-intl-idn/Idn.php',
    'Google\\Site_Kit_Dependencies\\Symfony\\Polyfill\\Intl\\Idn\\Info' => $baseDir . '/symfony/polyfill-intl-idn/Info.php',
    'Google\\Site_Kit_Dependencies\\Symfony\\Polyfill\\Intl\\Idn\\Resources\\unidata\\DisallowedRanges' => $baseDir . '/symfony/polyfill-intl-idn/Resources/unidata/DisallowedRanges.php',
    'Google\\Site_Kit_Dependencies\\Symfony\\Polyfill\\Intl\\Idn\\Resources\\unidata\\Regex' => $baseDir . '/symfony/polyfill-intl-idn/Resources/unidata/Regex.php',
    'Google\\Site_Kit_Dependencies\\Symfony\\Polyfill\\Intl\\Normalizer\\Normalizer' => $baseDir . '/symfony/polyfill-intl-normalizer/Normalizer.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Common\\Functions\\Strings' => $baseDir . '/phpseclib/phpseclib/phpseclib/Common/Functions/Strings.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\AES' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/AES.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Blowfish' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Blowfish.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\ChaCha20' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/ChaCha20.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Common\\AsymmetricKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/AsymmetricKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Common\\BlockCipher' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/BlockCipher.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Common\\Formats\\Keys\\JWK' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/JWK.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Common\\Formats\\Keys\\OpenSSH' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/OpenSSH.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Common\\Formats\\Keys\\PKCS' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/PKCS.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Common\\Formats\\Keys\\PKCS1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/PKCS1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Common\\Formats\\Keys\\PKCS8' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/PKCS8.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Common\\Formats\\Keys\\PuTTY' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Keys/PuTTY.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Common\\Formats\\Signature\\Raw' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Formats/Signature/Raw.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Common\\PrivateKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/PrivateKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Common\\PublicKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/PublicKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Common\\StreamCipher' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/StreamCipher.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Common\\SymmetricKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/SymmetricKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Common\\Traits\\Fingerprint' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Traits/Fingerprint.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Common\\Traits\\PasswordProtected' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Common/Traits/PasswordProtected.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DES' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DES.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DH' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DH.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DH\\Formats\\Keys\\PKCS1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DH/Formats/Keys/PKCS1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DH\\Formats\\Keys\\PKCS8' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DH/Formats/Keys/PKCS8.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DH\\Parameters' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DH/Parameters.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DH\\PrivateKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DH/PrivateKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DH\\PublicKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DH/PublicKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DSA' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DSA\\Formats\\Keys\\OpenSSH' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/OpenSSH.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DSA\\Formats\\Keys\\PKCS1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/PKCS1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DSA\\Formats\\Keys\\PKCS8' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/PKCS8.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DSA\\Formats\\Keys\\PuTTY' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/PuTTY.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DSA\\Formats\\Keys\\Raw' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/Raw.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DSA\\Formats\\Keys\\XML' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Keys/XML.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DSA\\Formats\\Signature\\ASN1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Signature/ASN1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DSA\\Formats\\Signature\\Raw' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Signature/Raw.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DSA\\Formats\\Signature\\SSH2' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Formats/Signature/SSH2.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DSA\\Parameters' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/Parameters.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DSA\\PrivateKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/PrivateKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\DSA\\PublicKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/DSA/PublicKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\BaseCurves\\Base' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/Base.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\BaseCurves\\Binary' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/Binary.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\BaseCurves\\KoblitzPrime' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/KoblitzPrime.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\BaseCurves\\Montgomery' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/Montgomery.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\BaseCurves\\Prime' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/Prime.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\BaseCurves\\TwistedEdwards' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/BaseCurves/TwistedEdwards.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\Curve25519' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/Curve25519.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\Curve448' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/Curve448.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\Ed25519' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/Ed25519.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\Ed448' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/Ed448.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP160r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP160r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP160t1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP160t1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP192r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP192r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP192t1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP192t1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP224r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP224r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP224t1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP224t1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP256r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP256r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP256t1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP256t1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP320r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP320r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP320t1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP320t1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP384r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP384r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP384t1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP384t1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP512r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP512r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\brainpoolP512t1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/brainpoolP512t1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\nistb233' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistb233.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\nistb409' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistb409.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\nistk163' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistk163.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\nistk233' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistk233.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\nistk283' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistk283.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\nistk409' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistk409.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\nistp192' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistp192.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\nistp224' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistp224.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\nistp256' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistp256.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\nistp384' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistp384.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\nistp521' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistp521.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\nistt571' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/nistt571.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\prime192v1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime192v1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\prime192v2' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime192v2.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\prime192v3' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime192v3.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\prime239v1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime239v1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\prime239v2' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime239v2.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\prime239v3' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime239v3.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\prime256v1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/prime256v1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\secp112r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp112r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\secp112r2' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp112r2.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\secp128r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp128r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\secp128r2' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp128r2.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\secp160k1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp160k1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\secp160r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp160r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\secp160r2' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp160r2.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\secp192k1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp192k1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\secp192r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp192r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\secp224k1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp224k1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\secp224r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp224r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\secp256k1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp256k1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\secp256r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp256r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\secp384r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp384r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\secp521r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/secp521r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect113r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect113r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect113r2' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect113r2.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect131r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect131r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect131r2' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect131r2.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect163k1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect163k1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect163r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect163r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect163r2' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect163r2.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect193r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect193r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect193r2' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect193r2.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect233k1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect233k1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect233r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect233r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect239k1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect239k1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect283k1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect283k1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect283r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect283r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect409k1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect409k1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect409r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect409r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect571k1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect571k1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Curves\\sect571r1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Curves/sect571r1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\Common' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/Common.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\JWK' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/JWK.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\MontgomeryPrivate' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/MontgomeryPrivate.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\MontgomeryPublic' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/MontgomeryPublic.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\OpenSSH' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/OpenSSH.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\PKCS1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/PKCS1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\PKCS8' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/PKCS8.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\PuTTY' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/PuTTY.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\XML' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/XML.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Formats\\Keys\\libsodium' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Keys/libsodium.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Formats\\Signature\\ASN1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Signature/ASN1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Formats\\Signature\\IEEE' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Signature/IEEE.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Formats\\Signature\\Raw' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Signature/Raw.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Formats\\Signature\\SSH2' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Formats/Signature/SSH2.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\Parameters' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/Parameters.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\PrivateKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/PrivateKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\EC\\PublicKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/EC/PublicKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Hash' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Hash.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\PublicKeyLoader' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/PublicKeyLoader.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\RC2' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/RC2.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\RC4' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/RC4.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\RSA' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\JWK' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/JWK.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\MSBLOB' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/MSBLOB.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\OpenSSH' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/OpenSSH.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\PKCS1' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/PKCS1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\PKCS8' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/PKCS8.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\PSS' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/PSS.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\PuTTY' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/PuTTY.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\Raw' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/Raw.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\RSA\\Formats\\Keys\\XML' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/Formats/Keys/XML.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\RSA\\PrivateKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/PrivateKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\RSA\\PublicKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/RSA/PublicKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Random' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Random.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Rijndael' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Rijndael.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Salsa20' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Salsa20.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\TripleDES' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/TripleDES.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Crypt\\Twofish' => $baseDir . '/phpseclib/phpseclib/phpseclib/Crypt/Twofish.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\BadConfigurationException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/BadConfigurationException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\BadDecryptionException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/BadDecryptionException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\BadModeException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/BadModeException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\ConnectionClosedException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/ConnectionClosedException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\FileNotFoundException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/FileNotFoundException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\InconsistentSetupException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/InconsistentSetupException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\InsufficientSetupException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/InsufficientSetupException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\InvalidPacketLengthException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/InvalidPacketLengthException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\NoKeyLoadedException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/NoKeyLoadedException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\NoSupportedAlgorithmsException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/NoSupportedAlgorithmsException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\TimeoutException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/TimeoutException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\UnableToConnectException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/UnableToConnectException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\UnsupportedAlgorithmException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/UnsupportedAlgorithmException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\UnsupportedCurveException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/UnsupportedCurveException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\UnsupportedFormatException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/UnsupportedFormatException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Exception\\UnsupportedOperationException' => $baseDir . '/phpseclib/phpseclib/phpseclib/Exception/UnsupportedOperationException.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ANSI' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ANSI.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Element' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Element.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\AccessDescription' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AccessDescription.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\AdministrationDomainName' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AdministrationDomainName.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\AlgorithmIdentifier' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AlgorithmIdentifier.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\AnotherName' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AnotherName.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\Attribute' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Attribute.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\AttributeType' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AttributeType.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\AttributeTypeAndValue' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AttributeTypeAndValue.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\AttributeValue' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AttributeValue.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\Attributes' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Attributes.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\AuthorityInfoAccessSyntax' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AuthorityInfoAccessSyntax.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\AuthorityKeyIdentifier' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/AuthorityKeyIdentifier.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\BaseDistance' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/BaseDistance.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\BasicConstraints' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/BasicConstraints.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\BuiltInDomainDefinedAttribute' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/BuiltInDomainDefinedAttribute.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\BuiltInDomainDefinedAttributes' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/BuiltInDomainDefinedAttributes.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\BuiltInStandardAttributes' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/BuiltInStandardAttributes.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\CPSuri' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CPSuri.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\CRLDistributionPoints' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CRLDistributionPoints.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\CRLNumber' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CRLNumber.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\CRLReason' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CRLReason.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\CertPolicyId' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertPolicyId.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\Certificate' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Certificate.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\CertificateIssuer' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificateIssuer.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\CertificateList' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificateList.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\CertificatePolicies' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificatePolicies.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\CertificateSerialNumber' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificateSerialNumber.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\CertificationRequest' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificationRequest.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\CertificationRequestInfo' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CertificationRequestInfo.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\Characteristic_two' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Characteristic_two.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\CountryName' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/CountryName.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\Curve' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Curve.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\DHParameter' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DHParameter.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\DSAParams' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DSAParams.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\DSAPrivateKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DSAPrivateKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\DSAPublicKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DSAPublicKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\DigestInfo' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DigestInfo.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\DirectoryString' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DirectoryString.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\DisplayText' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DisplayText.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\DistributionPoint' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DistributionPoint.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\DistributionPointName' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DistributionPointName.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\DssSigValue' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/DssSigValue.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\ECParameters' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ECParameters.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\ECPoint' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ECPoint.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\ECPrivateKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ECPrivateKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\EDIPartyName' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/EDIPartyName.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\EcdsaSigValue' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/EcdsaSigValue.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\EncryptedData' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/EncryptedData.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\EncryptedPrivateKeyInfo' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/EncryptedPrivateKeyInfo.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\ExtKeyUsageSyntax' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ExtKeyUsageSyntax.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\Extension' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Extension.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\ExtensionAttribute' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ExtensionAttribute.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\ExtensionAttributes' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ExtensionAttributes.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\Extensions' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Extensions.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\FieldElement' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/FieldElement.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\FieldID' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/FieldID.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\GeneralName' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/GeneralName.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\GeneralNames' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/GeneralNames.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\GeneralSubtree' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/GeneralSubtree.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\GeneralSubtrees' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/GeneralSubtrees.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\HashAlgorithm' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/HashAlgorithm.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\HoldInstructionCode' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/HoldInstructionCode.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\InvalidityDate' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/InvalidityDate.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\IssuerAltName' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/IssuerAltName.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\IssuingDistributionPoint' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/IssuingDistributionPoint.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\KeyIdentifier' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/KeyIdentifier.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\KeyPurposeId' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/KeyPurposeId.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\KeyUsage' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/KeyUsage.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\MaskGenAlgorithm' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/MaskGenAlgorithm.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\Name' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Name.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\NameConstraints' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/NameConstraints.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\NetworkAddress' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/NetworkAddress.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\NoticeReference' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/NoticeReference.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\NumericUserIdentifier' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/NumericUserIdentifier.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\ORAddress' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ORAddress.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\OneAsymmetricKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/OneAsymmetricKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\OrganizationName' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/OrganizationName.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\OrganizationalUnitNames' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/OrganizationalUnitNames.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\OtherPrimeInfo' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/OtherPrimeInfo.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\OtherPrimeInfos' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/OtherPrimeInfos.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PBEParameter' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PBEParameter.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PBES2params' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PBES2params.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PBKDF2params' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PBKDF2params.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PBMAC1params' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PBMAC1params.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PKCS9String' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PKCS9String.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\Pentanomial' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Pentanomial.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PersonalName' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PersonalName.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PolicyInformation' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PolicyInformation.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PolicyMappings' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PolicyMappings.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PolicyQualifierId' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PolicyQualifierId.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PolicyQualifierInfo' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PolicyQualifierInfo.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PostalAddress' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PostalAddress.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\Prime_p' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Prime_p.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PrivateDomainName' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PrivateDomainName.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PrivateKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PrivateKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PrivateKeyInfo' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PrivateKeyInfo.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PrivateKeyUsagePeriod' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PrivateKeyUsagePeriod.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PublicKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PublicKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PublicKeyAndChallenge' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PublicKeyAndChallenge.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\PublicKeyInfo' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/PublicKeyInfo.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\RC2CBCParameter' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RC2CBCParameter.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\RDNSequence' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RDNSequence.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\RSAPrivateKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RSAPrivateKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\RSAPublicKey' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RSAPublicKey.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\RSASSA_PSS_params' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RSASSA_PSS_params.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\ReasonFlags' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/ReasonFlags.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\RelativeDistinguishedName' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RelativeDistinguishedName.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\RevokedCertificate' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/RevokedCertificate.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\SignedPublicKeyAndChallenge' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SignedPublicKeyAndChallenge.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\SpecifiedECDomain' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SpecifiedECDomain.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\SubjectAltName' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SubjectAltName.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\SubjectDirectoryAttributes' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SubjectDirectoryAttributes.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\SubjectInfoAccessSyntax' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SubjectInfoAccessSyntax.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\SubjectPublicKeyInfo' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/SubjectPublicKeyInfo.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\TBSCertList' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/TBSCertList.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\TBSCertificate' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/TBSCertificate.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\TerminalIdentifier' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/TerminalIdentifier.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\Time' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Time.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\Trinomial' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Trinomial.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\UniqueIdentifier' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/UniqueIdentifier.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\UserNotice' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/UserNotice.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\Validity' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/Validity.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\netscape_ca_policy_url' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/netscape_ca_policy_url.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\netscape_cert_type' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/netscape_cert_type.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\ASN1\\Maps\\netscape_comment' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/ASN1/Maps/netscape_comment.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\File\\X509' => $baseDir . '/phpseclib/phpseclib/phpseclib/File/X509.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\BCMath' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\Base' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/Base.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\BuiltIn' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/BuiltIn.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\DefaultEngine' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/DefaultEngine.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\OpenSSL' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/OpenSSL.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\Reductions\\Barrett' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/Reductions/Barrett.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\BCMath\\Reductions\\EvalBarrett' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/BCMath/Reductions/EvalBarrett.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\Engine' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/Engine.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\GMP' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/GMP.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\GMP\\DefaultEngine' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/GMP/DefaultEngine.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\OpenSSL' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/OpenSSL.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\PHP' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\PHP32' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP32.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\PHP64' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP64.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Base' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Base.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\DefaultEngine' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/DefaultEngine.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Montgomery' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Montgomery.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\OpenSSL' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/OpenSSL.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\Barrett' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/Barrett.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\Classic' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/Classic.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\EvalBarrett' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/EvalBarrett.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\Montgomery' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/Montgomery.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\MontgomeryMult' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/MontgomeryMult.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BigInteger\\Engines\\PHP\\Reductions\\PowerOfTwo' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BigInteger/Engines/PHP/Reductions/PowerOfTwo.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BinaryField' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BinaryField.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\BinaryField\\Integer' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/BinaryField/Integer.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\Common\\FiniteField' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/Common/FiniteField.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\Common\\FiniteField\\Integer' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/Common/FiniteField/Integer.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\PrimeField' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/PrimeField.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Math\\PrimeField\\Integer' => $baseDir . '/phpseclib/phpseclib/phpseclib/Math/PrimeField/Integer.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Net\\SCP' => $baseDir . '/phpseclib/phpseclib/phpseclib/Net/SCP.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Net\\SFTP' => $baseDir . '/phpseclib/phpseclib/phpseclib/Net/SFTP.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Net\\SFTP\\Stream' => $baseDir . '/phpseclib/phpseclib/phpseclib/Net/SFTP/Stream.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\Net\\SSH2' => $baseDir . '/phpseclib/phpseclib/phpseclib/Net/SSH2.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\System\\SSH\\Agent' => $baseDir . '/phpseclib/phpseclib/phpseclib/System/SSH/Agent.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\System\\SSH\\Agent\\Identity' => $baseDir . '/phpseclib/phpseclib/phpseclib/System/SSH/Agent/Identity.php',
    'Google\\Site_Kit_Dependencies\\phpseclib3\\System\\SSH\\Common\\Traits\\ReadBytes' => $baseDir . '/phpseclib/phpseclib/phpseclib/System/SSH/Common/Traits/ReadBytes.php',
);
